@@ -187,7 +187,11 @@ impl Debug for State {
         for (r, chunk) in self.container.chunks(self.dim_c).enumerate() {
             for (c, block) in chunk.iter().enumerate() {
                 if self.player == (r, c) {
-                    f.write_char('x')?;
+                    if self.targets.contains(&(r, c)) {
+                        f.write_char('X')?;
+                    } else {
+                        f.write_char('x')?;
+                    }
                 } else if self.targets.contains(&(r, c)) {
                     if block == &Block::Crate {
                         f.write_char('M')?;
@@ -232,6 +236,19 @@ mod tests {
         State::new(raw, player, Vec::new(), rows, cols).unwrap()
     }
 
+    fn generate_basic_with_targets() -> State {
+        let rows = 5;
+        let cols = 5;
+        let mut raw = vec![Block::Wall; rows * cols];
+        let player = (2, 2);
+        raw[11] = Block::Floor;
+        raw[12] = Block::Floor;
+        raw[13] = Block::Floor;
+        let targets = vec![player];
+
+        State::new(raw, player, targets, rows, cols).unwrap()
+    }
+
     fn generate_hallway(width: usize) -> SokobanResult<State> {
         let rows = 3;
         let cols = width;
@@ -296,6 +313,19 @@ mod tests {
 "#);
     }
 
+    #[test]
+    fn basic_on_target_works() {
+        let state = generate_basic_with_targets();
+        let debug_string = format!("{:?}", state);
+        assert_eq!(debug_string, r#"
+#####
+#####
+#_X_#
+#####
+#####
+"#);
+    }
+
     #[test]
     fn basic_invalid_wall_doesnt_work() {
         let state = State::new(vec![Block::Wall], (0, 0), Vec::new(), 1, 1);
